@@ -36,13 +36,13 @@ def hist(data=None,x=None,y=None, width=200,height=50,filters=[],color=None,fill
     
     if interactive:
 
-      x_brush = alt.selection_interval(encodings=['x'],resolve="union",name='brush')
+      brush = alt.selection_interval(encodings=['x'],resolve="union",name='brush')
       
       if isinstance(interactive,alt.Selection):
-        x_brush = interactive     
+        brush = interactive     
       
-      layers['fg'] =  layers['fg'].add_selection(x_brush)
-      filters.append(x_brush)
+      layers['fg'] =  layers['fg'].add_selection(brush)
+      filters.append(brush)
 
 
   elif x is  None and y is not None:
@@ -55,14 +55,14 @@ def hist(data=None,x=None,y=None, width=200,height=50,filters=[],color=None,fill
     
     if interactive:
 
-      y_brush = alt.selection_interval(encodings=['y'],resolve="union",name='brush')
+      brush = alt.selection_interval(encodings=['y'],resolve="union",name='brush')
       
       if isinstance(interactive,alt.Selection):
-        y_brush = interactive     
+        brush = interactive     
 
       
-      layers['fg'] =  layers['fg'].add_selection(y_brush)
-      filters.append(y_brush)
+      layers['fg'] =  layers['fg'].add_selection(brush)
+      filters.append(brush)
   
 
   if filters:
@@ -78,8 +78,6 @@ def hist(data=None,x=None,y=None, width=200,height=50,filters=[],color=None,fill
 
 
 
-
-
 def violin_plots(data=None,y=None,groupby=None, yAxis=None,xAxis=alt.Axis(labels=False, values=[0],grid=False, ticks=True)):
   facet_vars = [None]
   if groupby:
@@ -113,12 +111,12 @@ def violin_plots(data=None,y=None,groupby=None, yAxis=None,xAxis=alt.Axis(labels
 
 
     base = base.transform_density(
-        'Miles_per_Gallon',
-        as_=['Miles_per_Gallon', 'density'],
+        y,
+        as_=[y, 'density'],
         extent=[5, 55],
     ).transform_stack(
         stack= "density",
-        groupby= ["Miles_per_Gallon"],
+        groupby= [y],
       as_= ["x", "x2"],
       offset= "center"
     )
@@ -131,7 +129,7 @@ def violin_plots(data=None,y=None,groupby=None, yAxis=None,xAxis=alt.Axis(labels
     layers['bg'] = base.mark_area(color="lightgray",
                                   ).encode(
                     
-        y=alt.Y('Miles_per_Gallon:Q',axis=yAxis),
+        y=alt.Y(f'{y}:Q',axis=yAxis),
         x=alt.X(
             field='x',
             impute=None,
@@ -147,7 +145,7 @@ def violin_plots(data=None,y=None,groupby=None, yAxis=None,xAxis=alt.Axis(labels
 
     layers['fg'] = base.mark_area(orient='horizontal', align="center",
                                   ).encode(
-        y=alt.Y('Miles_per_Gallon:Q',axis=yAxis),
+        y=alt.Y(f'{y}:Q',axis=yAxis),
         x=alt.X(
             field='x',
             impute=None,
@@ -162,9 +160,9 @@ def violin_plots(data=None,y=None,groupby=None, yAxis=None,xAxis=alt.Axis(labels
     ).transform_filter(
         brush
     )
-
+                    
     chrt = layers['bg'] + layers['fg']
-    charts.append(chrt.properties(width=100))
+    charts.append(chrt.properties(width=100,title = alt.TitleParams(text = variable )))
 
   final_chart = None
   for chart in charts:
@@ -172,4 +170,42 @@ def violin_plots(data=None,y=None,groupby=None, yAxis=None,xAxis=alt.Axis(labels
       final_chart = chart
     else:
       final_chart = alt.hconcat(final_chart,chart,spacing=0)
-  return final_chart
\ No newline at end of file
+  return final_chart
+
+
+def countplot(data=None,x=None,xAxis=alt.Axis(),yAxis=alt.Axis(), interactive=False, filters=[],width=250,height=150, max_bars = None):
+  if data is None:
+    if x is None:
+      raise ValueError('[countplot] no data or data series provided.')
+    data = pd.DataFrame({})
+    if isinstance(x, pd.Series):
+      data['x'] = x
+      x = 'x'
+
+  layers = {"fg":alt.Chart(data).mark_bar(color="steelblue")
+    .encode(
+      alt.X(f'{x}:N',axis=xAxis), # remove the sort as that will keep it consistent with the background
+            alt.Y(f'count({x}):Q',axis=yAxis)
+  ),"bg":alt.Chart(data).mark_bar(color="lightgray")
+    .encode(
+      alt.X(f'{x}:N',sort='-y',axis=xAxis), 
+      alt.Y(f'count({x}):Q',axis=yAxis)
+  )}
+
+  if interactive:
+      x_brush = alt.selection_multi(name='brush',encodings=['x'],resolve='union')
+      if isinstance(interactive,alt.Selection):
+        x_brush = interactive     
+      
+      layers['bg'] =  layers['bg'].add_selection(x_brush)
+      filters.append(x_brush)
+   
+  if filters:
+     for filter in filters:
+        layers['fg'] = layers['fg'].transform_filter(filter)
+
+  chart = layers['bg'] + layers['fg'] 
+  return chart.properties(
+          width=width,
+          height=height
+      )
\ No newline at end of file
